@@ -69,7 +69,7 @@ typedef struct xobject xobject;
 #define MAXPSFAKESTACK 32  /* Max depth of fake PostScript stack (local) */
 #define MAXSTRLEN 512      /* Max length of a Type 1 string (local) */
 #define MAXLABEL 256       /* Maximum number of new hints */
-#define MAXSTEMS 128       /* Maximum number of VSTEM and HSTEM hints */
+#define MAXSTEMS 512       /* Maximum number of VSTEM and HSTEM hints */
 #define EPS 0.001          /* Small number for comparisons */
  
 /************************************/
@@ -92,7 +92,15 @@ typedef struct xobject xobject;
 #define HMOVETO     22
 #define VHCURVETO   30
 #define HVCURVETO   31
- 
+
+/* The following charstring code appears in some old Adobe font files
+   in space and .notdef character and does not seems to do anything
+   useful aside from taking two args from the stack. We allow this
+   command and ignore it. The source code of ghostscript states that
+   this command is obsolete *and* undocumented.
+   This code may also appear in an Escape-sequence! */
+#define UNKNOWN_15  15
+
 /*******************************************/
 /* Adobe Type 1 CharString Escape commands */
 /*******************************************/
@@ -133,9 +141,7 @@ static LONG tmpi;    /* Store converted value in tmpi to avoid re-evaluation */
 #define ROUND(x) FLOOR((x) + 0.5)
 #define ODD(x) (((int)(x)) & 01)
 
-int currentchar = -1; /* for error reporting */
-
-#define CC IfTrace1(TRUE, "'%03o ", currentchar)
+#define CC IfTrace1(TRUE, "Char \"%s\": ", currentchar)
 
 /* To make some compiler happy we have to care about return  types! */
 #define Errori {errflag = TRUE; return 0;}    /* integer */
@@ -174,6 +180,7 @@ static int errflag;
 /* Global variables to hold Type1Char parameters */
 /*************************************************/
 static char *Environment;
+static char *currentchar;
 static struct XYspace *CharSpace;
 static psobj *CharStringP, *SubrsP, *OtherSubrsP;
 static int *ModeP;
@@ -481,7 +488,7 @@ int stemno;
     if (blues->StdVW != 0)      /* there is an entry for StdVW */
       widthdiff = blues->StdVW - stemwidth;
     for (i = 0; i < blues->numStemSnapV; ++i) { /* now look at StemSnapV */
-      if (blues->StemSnapV[i] - stemwidth < widthdiff)
+      if (FABS(blues->StemSnapV[i] - stemwidth) < FABS(widthdiff))
         /* this standard width is the best match so far for this stem */
         widthdiff = blues->StemSnapV[i] - stemwidth;
     }
@@ -489,7 +496,7 @@ int stemno;
     if (blues->StdHW != 0)      /* there is an entry for StdHW */
       widthdiff = blues->StdHW - stemwidth;
     for (i = 0; i < blues->numStemSnapH; ++i) { /* now look at StemSnapH */
-      if (blues->StemSnapH[i] - stemwidth < widthdiff)
+      if (FABS(blues->StemSnapH[i] - stemwidth) < FABS(widthdiff))
         /* this standard width is the best match so far for this stem */
         widthdiff = blues->StemSnapH[i] - stemwidth;
     }
@@ -557,8 +564,8 @@ int stemno;
       if (unitpixels < blues->BlueScale){
         suppressovershoot = TRUE;
       }
-      else
-        if (alignmentzones[i].topzone)
+      else{
+        if (alignmentzones[i].topzone){
           if (stemtop >= alignmentzones[i].bottomy + blues->BlueShift){
             enforceovershoot = TRUE;
 	  }
@@ -566,6 +573,9 @@ int stemno;
           if (stembottom <= alignmentzones[i].topy - blues->BlueShift){
             enforceovershoot = TRUE;
 	  }
+	}
+      }
+      
       
       /*************************************************/
       /* ALIGN THE FLAT POSITION OF THE ALIGNMENT ZONE */
@@ -601,21 +611,25 @@ int stemno;
         /* ENFORCE overshoot by shifting the entire stem (if necessary) so that
            it falls at least one pixel beyond the flat position. */
  
-        if (enforceovershoot)
-          if (overshoot < onepixel)
+        if (enforceovershoot){
+          if (overshoot < onepixel){
             if (alignmentzones[i].topzone)
               stemshift += onepixel - overshoot;
             else
               stemshift -= onepixel - overshoot;
+	  }
+	}
+	
  
         /* SUPPRESS overshoot by aligning the stem to the alignment zone's
            flat position. */
  
-        if (suppressovershoot)
+        if (suppressovershoot){
           if (alignmentzones[i].topzone)
             stemshift -= overshoot;
           else
             stemshift += overshoot;
+	}
       }
  
       /************************************************************/
@@ -878,8 +892,9 @@ static int PSFakePush(Num)
 static DOUBLE PSFakePop ()
 {
   if (PSFakeTop >= 0) return(PSFakeStack[PSFakeTop--]);
+  
   else Error0d("PSFakePop : Stack empty\n");
-  return(0.0);
+
   /*NOTREACHED*/
 }
  
@@ -972,7 +987,15 @@ static int DoRead(CodeP)
   int *CodeP;
 {
   if (strindex >= CharStringP->len) return(FALSE); /* end of string */
-  *CodeP = Decrypt((unsigned char) CharStringP->data.stringP[strindex++]);
+  /* We handle the non-documented Adobe convention to use lenIV=-1 to
+     suppress charstring encryption. */
+  if (blues->lenIV==-1) {
+    *CodeP = (unsigned char) CharStringP->data.stringP[strindex++];
+  }
+  else { 
+    *CodeP = Decrypt((unsigned char) CharStringP->data.stringP[strindex++]);
+  }
+  
   return(TRUE);
 }
  
@@ -1210,6 +1233,10 @@ static int DoCommand(Code)
       RRCurveTo(Stack[0], 0.0, Stack[1], Stack[2], 0.0, Stack[3]);
       ClearStack();
       break;
+  case UNKNOWN_15:
+    if (Top < 1) Error1i("DoCommand: Stack low (Code=%d)\n", Code);
+    ClearStack();
+    break;
     default: /* Unassigned command code */
 #ifdef DoCommandDebug
       printf("DoCommand: Unassigned\n");
@@ -1298,17 +1325,21 @@ static int Escape(Code)
       /* onto the Type 1 BuildChar operand stack */
       Push(PSFakePop());
       break;
-    case SETCURRENTPOINT: /* |- x y SETCURRENTPOINT |- */
-      /* Sets the current point to (x,y) in absolute */
-      /* character space coordinates without per- */
-      /* forming a CharString MOVETO command */
-      if (Top < 1) Error1i("DoCommand: Stack low (Code=%d)\n", Code);
-      SetCurrentPoint(Stack[0], Stack[1]);
-      ClearStack();
-      break;
-    default: /* Unassigned escape code command */
-      ClearStack();
-      Error1i("Escape: Unassigned code %d\n", Code);
+  case SETCURRENTPOINT: /* |- x y SETCURRENTPOINT |- */
+    /* Sets the current point to (x,y) in absolute */
+    /* character space coordinates without per- */
+    /* forming a CharString MOVETO command */
+    if (Top < 1) Error1i("DoCommand: Stack low (Code=%d)\n", Code);
+    SetCurrentPoint(Stack[0], Stack[1]);
+    ClearStack();
+    break;
+  case UNKNOWN_15:
+    if (Top < 1) Error1i("DoCommand: Stack low (Code=%d)\n", Code);
+    ClearStack();
+    break;
+  default: /* Unassigned escape code command */
+    ClearStack();
+    Error1i("Escape: Unassigned code %d\n", Code);
   }
   return(0);
 
@@ -1537,7 +1568,6 @@ static int Seac(asb, adx, ady, bchar, achar)
   CharStringP = GetType1CharString(Environment, achar);
   if (CharStringP == NULL) {
      Error1i("Invalid accent ('%03o) in SEAC\n", achar);
-     return(0);
   }
   StartDecrypt();
  
@@ -1958,7 +1988,7 @@ struct xobject *Type1Char(psfont *env, struct XYspace *S,
 			  psobj *charstrP, psobj *subrsP,
 			  psobj *osubrsP,
 			  struct blues_struct *bluesP,
-			  int *modeP)
+			  int *modeP, char *charname)
 {
   int Code;
  
@@ -1966,6 +1996,7 @@ struct xobject *Type1Char(psfont *env, struct XYspace *S,
   errflag = FALSE;
  
   /* Make parameters available to all Type1 routines */
+  currentchar=charname;
   Environment = (char *)env;
   CharSpace = S; /* used when creating path elements */
   CharStringP = charstrP;
