@@ -1,12 +1,12 @@
 /*
- * Grace - Graphics for Exploratory Data Analysis
+ * Grace - GRaphing, Advanced Computation and Exploration of data
  * 
  * Home page: http://plasma-gate.weizmann.ac.il/Grace/
  * 
  * Copyright (c) 1991-95 Paul J Turner, Portland, OR
- * Copyright (c) 1996-98 GRACE Development Team
+ * Copyright (c) 1996-99 Grace Development Team
  * 
- * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
+ * Maintained by Evgeny Stambulchik
  * 
  * 
  *                           All Rights Reserved
@@ -52,7 +52,7 @@
 #include "defines.h"
 #include "globals.h"
 #include "utils.h"
-#include "protos.h"
+#include "parser.h"
 
 int dl_load_fast = TRUE; /* controls type of DL module load */
 /* TODO: make it tunable through a command */
@@ -63,12 +63,13 @@ int load_module(char *fname, char *dl_function, char *dl_key, int dl_type)
 
     int dlflag;
     void *handle;
-    char *error;
+    const char *error;
     symtab_entry newkey;
+    int retval;
     
     if ((dl_type < 0) || (dl_key == NULL) || (dl_function == NULL)) {
         errmsg("Improper call to load_module()");
-	return (1);
+	return RETURN_FAILURE;
     }
     
 #if defined(HAVE_DLOPEN)
@@ -82,17 +83,17 @@ int load_module(char *fname, char *dl_function, char *dl_key, int dl_type)
     dlflag = 1;
 #  endif
     
-    handle = (void *) dlopen (fname, dlflag);
+    handle = dlopen(fname, dlflag);
     if (!handle) {
-        errmsg ((char *) dlerror());
-        return (1);
+        errmsg(dlerror());
+        return RETURN_FAILURE;
     }
     
-    newkey.fnc = (double (*)()) dlsym(handle, dl_function);
-    if ((error = (char *) dlerror()) != NULL) {
+    newkey.data = dlsym(handle, dl_function);
+    if (!newkey.data && (error = dlerror()) != NULL) {
         errmsg(error);
         dlclose(handle);
-        return (1);
+        return RETURN_FAILURE;
     }
 
 #endif /* end dlopen interface */
@@ -116,10 +117,10 @@ int load_module(char *fname, char *dl_function, char *dl_key, int dl_type)
         errmsg("DL module initialization failed");
 # endif
 #endif
-        return (1);
+        return RETURN_FAILURE;
     }
     
-    if (shl_findsym(handle, dl_function, TYPE_UNDEFINED, &newkey.fnc) != NULL) {
+    if (shl_findsym(handle, dl_function, TYPE_UNDEFINED, &newkey.data) != NULL) {
 #if defined(HAVE_STRERROR)
         errmsg(strerror(errno));
 #else
@@ -130,24 +131,20 @@ int load_module(char *fname, char *dl_function, char *dl_key, int dl_type)
 # endif
 #endif
         shl_unload(handle);
-        return (1);
+        return RETURN_FAILURE;
     }
 
 #endif /* end shl_load interface */
 
     newkey.type = dl_type;
-    newkey.s = malloc(strlen(dl_key) + 1);
-    strcpy(newkey.s, dl_key);
-    lowtoupper(newkey.s);
+    newkey.s = copy_string(NULL, dl_key);
     
-    if (addto_symtab(newkey) != 0){
-        return (1);
-    } else {
-        return (0);
-    }
+    retval = addto_symtab(newkey);
+    xfree(newkey.s);
+    return retval;
 
 #else /* no support for DL */
     errmsg("No support for DL modules on your OS");
-    return (1);
+    return RETURN_FAILURE;
 #endif
 }
