@@ -6,7 +6,7 @@
  * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
  * Copyright (c) 1996-2003 Grace Development Team
  * 
- * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
+ * Maintained by Evgeny Stambulchik
  * 
  * 
  *                           All Rights Reserved
@@ -94,7 +94,7 @@ int init_t1(void)
         return (RETURN_FAILURE);
     }
     
-    fd = grace_openr(bufp, SOURCE_DISK);
+    fd = grace_openr("fonts/FontDataBase", SOURCE_DISK);
     if (fd == NULL) {
         return (RETURN_FAILURE);
     }
